EthPrecompileResult

Type Alias EthPrecompileResult 

pub type EthPrecompileResult = Result<EthPrecompileOutput, PrecompileHalt>;
A precompile operation result type for individual Ethereum precompile functions.

Returns either Ok(EthPrecompileOutput) or Err(PrecompileHalt).

Aliased Type

pub enum EthPrecompileResult {
    Ok(EthPrecompileOutput),
    Err(PrecompileHalt),
}

Variants

1.0.0

Ok(EthPrecompileOutput)

Contains the success value

1.0.0

Err(PrecompileHalt)

Contains the error value

Layout

Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.